Ryll is a simple and not particularly performant SPICE client written entirely in
python. It is useful for testing Kerbside, which is a SPICE protocol native
proxy used for supporting SPICE VDI sessions in cloud products.

By way of explaining the name, Ryll was the name of a narcotic form of the
medicinal spice mined on Kessel in Star Wars, although Ryll specifically came from
Ryloth according to https://starwars.fandom.com/wiki/Spice.
